# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: role_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12role_service.proto"2\n\x0eGetUserRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t" \n\x0fGetUserResponse\x12\r\n\x05\x65mail\x18\x01 \x01(\t"*\n\x12GetUserListRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t"\x1b\n\nUserInList\x12\r\n\x05\x65mail\x18\x01 \x01(\t"3\n\x13GetUserListResponse\x12\x1c\n\x07results\x18\x01 \x03(\x0b\x32\x0b.UserInList2s\n\tAdminRole\x12,\n\x07GetUser\x12\x0f.GetUserRequest\x1a\x10.GetUserResponse\x12\x38\n\x0bGetUserList\x12\x13.GetUserListRequest\x1a\x14.GetUserListResponseb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "role_service_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS is False:

    DESCRIPTOR._options = None
    _GETUSERREQUEST._serialized_start = 22
    _GETUSERREQUEST._serialized_end = 72
    _GETUSERRESPONSE._serialized_start = 74
    _GETUSERRESPONSE._serialized_end = 106
    _GETUSERLISTREQUEST._serialized_start = 108
    _GETUSERLISTREQUEST._serialized_end = 150
    _USERINLIST._serialized_start = 152
    _USERINLIST._serialized_end = 179
    _GETUSERLISTRESPONSE._serialized_start = 181
    _GETUSERLISTRESPONSE._serialized_end = 232
    _ADMINROLE._serialized_start = 234
    _ADMINROLE._serialized_end = 349
# @@protoc_insertion_point(module_scope)
